# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

#!/bin/bash

set -e

if [ "$(uname)" = "Linux" ]; then
  # github action runs on ubuntu, we might need to install python3 and pip3
  sudo apt-get update && sudo apt-get install python3 -y
  sudo apt install python3-pip
fi

# creating python virtual env
python3 -m venv ~/.python3venv
source ~/.python3venv/bin/activate
pip3 install wheel  # install wheel first explicitly
pip3 install --upgrade pyyaml
